Python package to by used as substitute of a real device manager running in a ELT-Software environment. 

The package is in somehow in between simple python opc-ua script client and a real integrated device manager on a workstation.  

Two main purposes: 

- Running AIT test from any computer. Ability to handle all hardware installed on a running PLC in a friendly environment and from non software engineers.
- Prototyping of special devices. Python coding of the opc-ua interface and main functions. 

Therefore the package is using the device manager configuration files of the ESO framework (v2.0). 

# Install

```bash
> pip install pydevmgr 
```

The Documentation is [here](http://www.efisoft.fr/documentation/pydevmgr/pydevmgr.html) 


